<?php

class UberInstallerScript
{
	/**
	 * Constructor
	 *
	 * @param   JAdapterInstance $adapter The object responsible for running this script
	 */
	public function __construct(JAdapterInstance $adapter)
	{
	}

	/**
	 * Called before any type of action
	 *
	 * @param   string $route Which action is happening (install|uninstall|discover_install|update)
	 * @param   JAdapterInstance $adapter The object responsible for running this script
	 *
	 * @return  boolean  True on success
	 */
	public function preflight($route, JAdapterInstance $adapter)
	{
	}

	/**
	 * Called after any type of action
	 *
	 * @param   string $route Which action is happening (install|uninstall|discover_install|update)
	 * @param   JAdapterInstance $adapter The object responsible for running this script
	 *
	 * @return  boolean  True on success
	 */
	public function postflight($route, JAdapterInstance $adapter)
	{
		$sqlfile = dirname (__FILE__) . '/sql/sample_data.sql';
		
		if (!is_file ($sqlfile)) {
			return;
		}
		
		$queries = $this->_splitQueries(file_get_contents ($sqlfile));
		$db = JFactory::getDBO();
		foreach ($queries as $query) {
			$query = trim($query);
			$db->setQuery ($query);
			if (!$db->execute()) {
			}
		}
		
		// update default menu item
		$query = "SELECT `id` FROM #__menu WHERE `home`=1 AND `client_id`=0";
		$db->setQuery ($query);
		if (!$db->loadResult ()) {
			// update the first item in mainmenu
			$query = "SELECT `id` FROM #__menu WHERE `menutype`='mainmenu' AND `client_id`=0 AND `published`=1 LIMIT 1";
			$db->setQuery ($query);
			$menuid = $db->loadResult ();
			if ($menuid) {
				$table = JTable::getInstance ('menu');
				$table->load ($menuid);
				$table->home = 1;
				$table->store();
			}
		}
		
		// disable plg_installer_jainstaller
		$table = JTable::getInstance ('extension');
		$eid = $table->find (array('type'=>'plugin', 'element' => 'jainstaller', 'folder' => 'installer'));
		if ($eid) {
			$table->load ($eid);
			$table->enabled = 0;
			$table->store();
		}
		
		// clean all cache
		$conf = JFactory::getConfig();
		// clean site cache
		$options = array(
			'defaultgroup'	=> '',
			'storage' 		=> $conf->get('cache_handler', ''),
			'caching'		=> true,
			'cachebase'		=> $conf->get('cache_path', JPATH_SITE . '/cache')
		);
		$cache = JCache::getInstance('', $options);
		$data = $cache->getAll();
		if (is_array($data)) {
			foreach ($data as $folder => $item) {
				$cache->clean($item->group);
			}
		}

	}

	/**
	 * Called on installation
	 *
	 * @param   JAdapterInstance $adapter The object responsible for running this script
	 *
	 * @return  boolean  True on success
	 */
	public function install(JAdapterInstance $adapter)
	{
	}

	/**
	 * Called on update
	 *
	 * @param   JAdapterInstance $adapter The object responsible for running this script
	 *
	 * @return  boolean  True on success
	 */
	public function update(JAdapterInstance $adapter)
	{
	}

	/**
	 * Called on uninstallation
	 *
	 * @param   JAdapterInstance $adapter The object responsible for running this script
	 */
	public function uninstall(JAdapterInstance $adapter)
	{
	}
	
	function _splitQueries($sql)
	{
		// Initialise variables.
		$buffer		= array();
		$queries	= array();
		$in_string	= false;

		// Trim any whitespace.
		$sql = trim($sql);

		// Remove comment lines.
		$sql = preg_replace("/\n\#[^\n]*/", '', "\n".$sql);

		// Parse the schema file to break up queries.
		for ($i = 0; $i < strlen($sql) - 1; $i ++)
		{
			if ($sql[$i] == ";" && !$in_string) {
				$queries[] = substr($sql, 0, $i);
				$sql = substr($sql, $i +1);
				$i = 0;
			}

			if ($in_string && ($sql[$i] == $in_string) && $buffer[1] != "\\") {
				$in_string = false;
			}
			elseif (!$in_string && ($sql[$i] == '"' || $sql[$i] == "'") && (!isset ($buffer[0]) || $buffer[0] != "\\")) {
				$in_string = $sql[$i];
			}
			if (isset ($buffer[1])) {
				$buffer[0] = $buffer[1];
			}
			$buffer[1] = $sql[$i];
		}

		// If the is anything left over, add it to the queries.
		if (!empty($sql)) {
			$queries[] = $sql;
		}

		return $queries;
	}	
}
